@@ -29,19 +29,23 @@ try:
                     dct["dtype"] = str(obj.dtype)
                 dct["datetimeindex"] = isinstance(obj.index, pd.DatetimeIndex)
                 return dct
-            elif isinstance(obj, np.ndarray):
+            if isinstance(obj, np.ndarray):
                 return dict(__ndarray__=obj.tolist(), dtype=str(obj.dtype), shape=obj.shape)
-            elif isinstance(obj, (datetime, pd.Timestamp)):
+            if isinstance(obj, (datetime, pd.Timestamp)):
                 return obj.strftime("%Y-%m-%d %H:%M:%S")
-            elif isinstance(obj, date):
+            if isinstance(obj, date):
                 return obj.strftime("%Y-%m-%d")
-            elif isinstance(obj, pd.Timedelta):
+            if isinstance(obj, pd.Timedelta):
                 return {"__pd.Timedelta__": str(obj)}
-            elif hasattr(obj, "name"):
+            if hasattr(obj, "name"):
                 return obj.name
-            else:
-                return json.JSONEncoder.default(self, obj)
-
+            if isinstance(obj, np.integer):
+                return int(obj)
+            if isinstance(obj, np.floating):
+                return float(obj)
+            if isinstance(obj, np.ndarray):
+                return obj.tolist()
+            return super(JSONEncoder, self).default(self, obj)
 
     def json_obj_hook(dct):
         if isinstance(dct, dict) and "__ndarray__" in dct:
@@ -116,11 +120,15 @@ try:
             self.change_suffix(".json")
         jsonified = json.dumps(data, cls=JSONEncoder)
         self.write_stuff(
-            jsonified, "w", overwrite=overwrite, present=present, **kwargs,
+            jsonified,
+            "w",
+            overwrite=overwrite,
+            present=present,
+            **kwargs,
         )
 
     def to_plotly_json(self):
-        """ For compatibility with Plotly Dash """
+        """For compatibility with Plotly Dash"""
         return str(self)
 
 
